@@ -32,8 +32,7 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkcombobox.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtksizegroup.h>
 #include <gtk/gtkspinbutton.h>
@@ -59,12 +58,12 @@ enum
 
 
 static void
-option_menu_changed (GtkWidget *option_menu,
-		     GConfKeyEditor *editor)
+combo_box_changed (GtkWidget *combo_box,
+		   GConfKeyEditor *editor)
 {
 	int index;
 
-	index = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+	index = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
 
 	editor->active_type = index;
 		
@@ -124,70 +123,62 @@ gconf_key_editor_list_entry_changed (GConfCellRenderer *cell, const gchar *path_
 }
 
 static void
-list_type_menu_changed (GtkWidget *option_menu,
+list_type_menu_changed (GtkWidget *combobox,
 			GConfKeyEditor *editor)
 {
 	gtk_list_store_clear (editor->list_model);
 }
 
 static GtkWidget *
-gconf_key_editor_create_option_menu (GConfKeyEditor *editor)
+gconf_key_editor_create_combo_box (GConfKeyEditor *editor)
 {
-	GtkWidget *option_menu, *menu;
+	GtkWidget *combo_box;
 
-	option_menu = gtk_option_menu_new ();
+	combo_box = gtk_combo_box_new_text ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
 	 * menu indices
 	 */
-	menu = gtk_menu_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Integer"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Boolean"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("String"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), 
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Float"))));
- 	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("List"))));
-	gtk_widget_show_all (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), (menu));
 
-	g_signal_connect (option_menu, "changed",
-			  G_CALLBACK (option_menu_changed),
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Float"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("List"));
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+
+	g_signal_connect (combo_box, "changed",
+			  G_CALLBACK (combo_box_changed),
 			  editor);
 	
-	gtk_widget_show_all (option_menu);
-	return option_menu;
+	gtk_widget_show_all (combo_box);
+	return combo_box;
 }
 
 static GtkWidget *
 gconf_key_editor_create_list_type_menu (GConfKeyEditor *editor)
 {
-	GtkWidget *option_menu, *menu;
+	GtkWidget *combo_box;
 
-	option_menu = gtk_option_menu_new ();
+	combo_box = gtk_combo_box_new_text ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
-	 * menu indices
+	 * combobox indices
 	 */
-	menu = gtk_menu_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Integer"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("Boolean"))));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu),
-			       GTK_WIDGET (gtk_menu_item_new_with_label (_("String"))));
-	gtk_widget_show_all (menu);
-        gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), (menu));
 
-	g_signal_connect (option_menu, "changed",
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+	
+	g_signal_connect (combo_box, "changed",
 			  G_CALLBACK (list_type_menu_changed),
 			  editor);
 
-        gtk_widget_show_all (option_menu);
-        return option_menu;
+        gtk_widget_show_all (combo_box);
+        return combo_box;
 }
 
 static void
@@ -198,26 +189,27 @@ update_list_buttons (GConfKeyEditor *editor)
 	GtkTreePath *path;
 	GtkTreeModel *model;
 	gint selected;
+	gboolean can_edit = FALSE, can_remove = FALSE, can_go_up = FALSE, can_go_down = FALSE;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->list_widget));
 
-	gtk_widget_set_sensitive (editor->remove_button, FALSE);
-	gtk_widget_set_sensitive (editor->edit_button, FALSE);
-	gtk_widget_set_sensitive (editor->go_up_button, FALSE);
-	gtk_widget_set_sensitive (editor->go_down_button, FALSE);
-
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		path = gtk_tree_model_get_path (model, &iter);
 
 		selected = gtk_tree_path_get_indices (path)[0];
 
-		gtk_widget_set_sensitive (editor->edit_button, TRUE);
-		gtk_widget_set_sensitive (editor->remove_button, TRUE);
-		gtk_widget_set_sensitive (editor->go_up_button, selected > 0);
-		gtk_widget_set_sensitive (editor->go_down_button, selected < gtk_tree_model_iter_n_children (model, NULL) - 1);
+		can_edit = can_remove = TRUE;
+		can_go_up = selected > 0;
+		can_go_down =  selected < gtk_tree_model_iter_n_children (model, NULL) - 1;
 
 		gtk_tree_path_free (path);
 	}
+
+	gtk_widget_set_sensitive (editor->remove_button, can_remove);
+	gtk_widget_set_sensitive (editor->edit_button, can_edit);
+	gtk_widget_set_sensitive (editor->go_up_button, can_go_up);
+	gtk_widget_set_sensitive (editor->go_down_button, can_go_down);
+
 }
 
 static void
@@ -258,7 +250,7 @@ list_add_clicked (GtkButton *button,
 	label = gtk_label_new_with_mnemonic (_("_New list value:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 		case EDIT_INTEGER:
 			value_widget = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1);
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (value_widget), 0);
@@ -290,7 +282,7 @@ list_add_clicked (GtkButton *button,
 		
 	        value = NULL;
 
-		switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			case EDIT_INTEGER:
 				value = gconf_value_new (GCONF_VALUE_INT);
 				gconf_value_set_int (value,
@@ -363,7 +355,7 @@ list_edit_element (GConfKeyEditor *editor)
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->list_widget));
 	gtk_tree_selection_get_selected (selection, &model, &iter);
 	gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 0, &value, -1);
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 		case EDIT_INTEGER:
 			value_widget = gtk_spin_button_new_with_range (G_MININT, G_MAXINT, 1);
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (value_widget), gconf_value_get_int (value));
@@ -394,7 +386,7 @@ list_edit_element (GConfKeyEditor *editor)
 		
 	        value = NULL;
 
-		switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			case EDIT_INTEGER:
 				value = gconf_value_new (GCONF_VALUE_INT);
 				gconf_value_set_int (value,
@@ -605,11 +597,11 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_size_group_add_widget (size_group, label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	editor->option_menu = gconf_key_editor_create_option_menu (editor);
+	editor->combobox = gconf_key_editor_create_combo_box (editor);
 	gtk_box_pack_start (GTK_BOX (hbox),
-			    editor->option_menu,
+			    editor->combobox,
 			    TRUE, TRUE, 0);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->option_menu);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), editor->combobox);
 	gtk_widget_show_all (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
@@ -847,24 +839,24 @@ gconf_key_editor_set_value (GConfKeyEditor *editor, GConfValue *value)
 		return;
 	}
 
-	gtk_widget_set_sensitive (editor->option_menu, FALSE);
+	gtk_widget_set_sensitive (editor->combobox, FALSE);
 	gtk_widget_set_sensitive (editor->list_type_menu, FALSE);
 
 	switch (value->type) {
 	case GCONF_VALUE_INT:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_INTEGER);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_INTEGER);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->int_widget), gconf_value_get_int (value));
 		break;
 	case GCONF_VALUE_STRING:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_STRING);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_STRING);
 		gtk_entry_set_text (GTK_ENTRY (editor->string_widget), gconf_value_get_string (value));
 		break;
 	case GCONF_VALUE_BOOL:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_BOOLEAN);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_BOOLEAN);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->bool_widget), gconf_value_get_bool (value));
 		break;
 	case GCONF_VALUE_FLOAT:
-		gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_FLOAT);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_FLOAT);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->float_widget), gconf_value_get_float (value));
 		break;
 	case GCONF_VALUE_LIST:
@@ -873,22 +865,22 @@ gconf_key_editor_set_value (GConfKeyEditor *editor, GConfValue *value)
 			
 			switch (gconf_value_get_list_type(value)) {
 				case GCONF_VALUE_INT:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_INTEGER);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_INTEGER);
 					break;
 				case GCONF_VALUE_FLOAT:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_FLOAT);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_FLOAT);
 					break;
 				case GCONF_VALUE_STRING:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_STRING);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_STRING);
 					break;
 				case GCONF_VALUE_BOOL:
-					gtk_option_menu_set_history (GTK_OPTION_MENU (editor->list_type_menu), EDIT_BOOLEAN);
+					gtk_combo_box_set_active (GTK_COMBO_BOX (editor->list_type_menu), EDIT_BOOLEAN);
 					break;
 				default:
 					g_assert_not_reached ();
 			}
 
-			gtk_option_menu_set_history (GTK_OPTION_MENU (editor->option_menu), EDIT_LIST);
+			gtk_combo_box_set_active (GTK_COMBO_BOX (editor->combobox), EDIT_LIST);
 				
 		        while (iter != NULL) {
 				GConfValue* element = (GConfValue*) iter->data;
@@ -961,7 +953,7 @@ gconf_key_editor_get_value (GConfKeyEditor *editor)
 
 			value = gconf_value_new (GCONF_VALUE_LIST);
 
-			switch (gtk_option_menu_get_history (GTK_OPTION_MENU (editor->list_type_menu))) {
+			switch (gtk_combo_box_get_active (GTK_COMBO_BOX (editor->list_type_menu))) {
 			        case EDIT_INTEGER:
 					gconf_value_set_list_type (value, GCONF_VALUE_INT);
 					break;
